<?php
// encoding: ISO-8859-1,fr.php,
/*        ---   INSTRUCTIONS FOR TRANSLATORS   ---
 *
 * If you want to write a new language file for your language,
 * please submit the file on SourceForge:
 *
 * https://sourceforge.net/tracker/?func=add&group_id=61828&atid=498548
 *
 * Use the option "Check to Upload and Attach a File" at the bottom
 *
 * Thank you!
 *
 * $Header: /cvsroot/phpldapadmin/phpldapadmin/lang/fr.php,v 1.25 2004/05/29 04:07:02 uugdave Exp $
 */

/*
 * The $lang array contains all the strings that phpLDAPadmin uses.
 * Each language file simply defines this aray with strings in its
 * language.
 */

//  Search form
$lang['simple_search_form_str'] = 'Recherche Simple';
$lang['advanced_search_form_str'] = 'Recherche avance';
$lang['server'] = 'Serveur';
$lang['search_for_entries_whose'] = 'Chercher les entres dont';
$lang['base_dn'] = 'Base DN';
$lang['search_scope'] = 'Porte de la recherche';
$lang['show_attributes'] = 'Montrer les attributs';
$lang['Search'] = 'Chercher';
$lang['equals'] = 'est gal ';
$lang['contains'] = 'contient';
$lang['predefined_search_str'] = 'Selectionner une recherche prdfinie';
$lang['predefined_searches'] = 'Recherches prdfinies';
$lang['no_predefined_queries'] = 'Aucune requte n\' a t dfinie dans config.php.';

// Tree browser
$lang['request_new_feature'] = 'Demander une nouvelle fonctionnalit';
$lang['report_bug'] = 'Signaler un bogue';
$lang['schema'] = 'schema';
$lang['search'] = 'chercher';
$lang['refresh'] = 'rafrachir';
$lang['create'] = 'crer';
$lang['info'] = 'info';
$lang['import'] = 'importer';
$lang['logout'] = 'se dconnecter';
$lang['create_new'] = 'Crer';
$lang['view_schema_for'] = 'Voir les schemas pour';
$lang['refresh_expanded_containers'] = 'Rafrachir tous les containeurs tendus';
$lang['create_new_entry_on'] = 'Crer une nouvelle entre sur';
$lang['new'] = 'nouveau';
$lang['view_server_info'] = 'Voir les informations sur le serveur';
$lang['import_from_ldif'] = 'Importer des entres  partir d\'un fichier LDIF';
$lang['logout_of_this_server'] = 'Se dconnecter de ce serveur';
$lang['logged_in_as'] = 'Connect en tant que: ';
$lang['read_only'] = 'Lecture seule';
$lang['could_not_determine_root'] = 'La racine de l\'arborescence Ldap n\'a pu tre dtermine.';
$lang['ldap_refuses_to_give_root'] = 'Il semble que le serveur LDAP a t configur de telle sorte que la racine ne soit pas rvele.';
$lang['please_specify_in_config'] = 'Veuillez le spcifier dans le fichier config.php';
$lang['create_new_entry_in'] = 'Crer une nouvelle entre dans';
$lang['login_link'] = 'Login...';
$lang['login'] = 'login';

// Entry display
$lang['delete_this_entry'] = 'Supprimer cette entre';
$lang['delete_this_entry_tooltip'] = 'Il vous sera demand confirmation';
$lang['copy_this_entry'] = 'Copier cette entre';
$lang['copy_this_entry_tooltip'] = 'Copier cet objet vers un autre endroit, un nouveau DN ou un autre serveur';
$lang['export'] = 'Exporter';
$lang['export_tooltip'] = 'Sauvegarder cet objet';
$lang['export_subtree_tooltip'] = 'Sauvegarder cet objet ainsi que tous les sous-objets';
$lang['export_subtree'] = 'Exporter l\'arborescence';
$lang['create_a_child_entry'] = 'Crer une sous-entre'; 
$lang['rename_entry'] = 'Renommer l\'entre';
$lang['rename'] = 'Renommer';
$lang['add'] = 'Ajouter';
$lang['view'] = 'Voir';
$lang['view_one_child'] = 'Voir 1 sous-entre';
$lang['view_children'] = 'Voir les %s sous-entres';
$lang['add_new_attribute'] = 'Ajouter un nouvel attribut';
$lang['add_new_objectclass'] = 'Ajouter une nouvelle classe d\'objet';
$lang['hide_internal_attrs'] = 'Cacher les attributs internes';
$lang['show_internal_attrs'] = 'Montrer les attributs internes';
$lang['attr_name_tooltip'] = 'Cliquer pour voir la dfinition de schma pour l\'attribut de type \'%s\'';
$lang['none'] = 'aucun'; 
$lang['save_changes'] = 'Sauver les modifications';
$lang['add_value'] = 'ajouter une valeur';
$lang['add_value_tooltip'] = 'Ajouter une valeur supplmentaire   cet attribut';
$lang['refresh_entry'] = 'Rafraichir';
$lang['refresh_this_entry'] = 'Rafrachir cette entre';
$lang['delete_hint'] = 'Note: Pour effacer un attribut, laissez le champs vide et cliquez pour sauvegarder.';
$lang['attr_schema_hint'] = 'Note: Pour voir le schma pour un attribut, cliquer sur le nom de l\'attribut.';
$lang['attrs_modified'] = 'Certains attributs (%s) ont t modifis et sont mis en vidence ci-dessous.';
$lang['attr_modified'] = 'Un attribut (%s) a t modifi et est mis en vidence ci-dessous.';
$lang['viewing_read_only'] = 'Voir une entre en lecture seule.';
$lang['no_new_attrs_available'] = 'plus d\'attributs disponibles pour cette entre';
$lang['no_new_binary_attrs_available'] = 'plus d\' attributs binaires disponibles pour cette entr';
$lang['binary_value'] = 'Valeur de type binaire';
$lang['add_new_binary_attr'] = 'Ajouter un nouvel attribut de type binaire';
$lang['alias_for'] = 'Alias pour';
$lang['download_value'] = 'Tlcharger le contenu';
$lang['delete_attribute'] = 'Supprimer l\'attribut';
$lang['true'] = 'vrai';
$lang['false'] = 'faux';
$lang['none_remove_value'] = 'aucun, suppression de la valeur';
$lang['really_delete_attribute'] = 'Voulez-vous vraiment supprimer l\'attribut';
$lang['add_new_value'] = 'Ajouter une nouvelle valeur';

// Schema browser
$lang['the_following_objectclasses'] = 'Les classes d\'objets (objectClasses) suivantes sont supports par ce serveur LDAP.';
$lang['the_following_attributes'] = 'Les types d\'attributs (attributesTypes) suivants sont supports par ce serveur LDAP.';
$lang['the_following_matching'] = 'Les oprateurs (matching rules) suivants sont supports par ce serveur LDAP.';
$lang['the_following_syntaxes'] = 'Les syntaxes suivantes sont supports par ce serveur LDAP.';
$lang['schema_retrieve_error_1']='Le serveur ne supporte pas entirement le protocol LDAP.';
$lang['schema_retrieve_error_2']='Votre version de PHP ne permet pas d\'excute correctement la requte.';
$lang['schema_retrieve_error_3']='Ou tout du moins, phpLDAPadmin ne sait pas comment rcuprer le schma pour votre serveur.';
$lang['jump_to_objectclass'] = 'Aller  une classe d\'objet';
$lang['jump_to_attr'] = 'Aller  un attribut';
$lang['jump_to_matching_rule'] = 'Aller  une rgle d\'galit';
$lang['schema_for_server'] = 'Schema pour le serveur';
$lang['required_attrs'] = 'Attributs obligatoires';
$lang['optional_attrs'] = 'Attributs optionnels';
$lang['optional_binary_attrs'] = 'Attributs binaires optionnels';
$lang['OID'] = 'OID';
$lang['aliases']='Alias';
$lang['desc'] = 'Description';
$lang['no_description']='aucune description';
$lang['name'] = 'Nom';
$lang['equality']='Egalit';
$lang['is_obsolete'] = 'Cette classe d\'objet est obsolete';
$lang['inherits'] = 'hrite';
$lang['inherited_from']='hrite de';
$lang['jump_to_this_oclass'] = 'Aller  la dfinition de cette classe d\'objet';
$lang['matching_rule_oid'] = 'OID de l\'oprateur';
$lang['syntax_oid'] = 'OID de la syntaxe';
$lang['not_applicable'] = 'not applicable';
$lang['not_specified'] = 'non spcifi';
$lang['character']='caractre'; 
$lang['characters']='caractres';
$lang['used_by_objectclasses']='Utilis par les objectClasses';
$lang['used_by_attributes']='Utilis par les attributes';
$lang['maximum_length']='Maximum Length';
$lang['attributes']='Types d\'attribut';
$lang['syntaxes']='Syntaxes';
$lang['objectclasses']='objectClasses';
$lang['matchingrules']='Rgles d\'galit';
$lang['oid']='OID';
$lang['obsolete']='Obsolte';
$lang['ordering']='Ordonn';
$lang['substring_rule']='Substring Rule';
$lang['single_valued']='Valeur Unique';
$lang['collective']='Collective';
$lang['user_modification']='Modification Utilisateur';
$lang['usage']='Usage';
$lang['maximum_length']='Longueur maximale';
$lang['could_not_retrieve_schema_from']='Impossible de rcuprer le schma de';
$lang['type']='Type';

// Deleting entries
$lang['entry_deleted_successfully'] = 'Suppression de l\'entre \'%s\' russie.';
$lang['you_must_specify_a_dn'] = 'Un DN doit tre spcifi';
$lang['could_not_delete_entry'] = 'Impossible de supprimer l\'entre: %s';
$lang['no_such_entry'] = 'Aucune entre de ce type: %s';
$lang['delete_dn'] = 'Delete %s';
$lang['permanently_delete_children'] = 'Effacer galement les sous-entres?';
$lang['entry_is_root_sub_tree'] = 'Cette entre est la racine d\'une arborescence contenant %s entres.';
$lang['view_entries'] = 'voir les entres';
$lang['confirm_recursive_delete'] = 'phpLDAPadmin peut supprimer cette entres ainsi que les %s noeuds enfants de faon rcursive. Voir ci-dessous pour une liste des entres que cette action suprimera. Voulez-vous continuer?';
$lang['confirm_recursive_delete_note'] = 'Note: ceci est potentiellement trs dangereux and vous fates cela  vos propres risques. Cette opration ne peut tre annule. Prenez en considration les alias ainsi que d\'autres choses qui pourraient causer des problmes.';
$lang['delete_all_x_objects'] = 'Suppressions des  %s objets';
$lang['recursive_delete_progress'] = 'Progression de la suppression rcursive';
$lang['entry_and_sub_tree_deleted_successfully'] = 'L\'entre %s ainsi que la sous-arborescence de ce noeud ont t supprims avec succs.';
$lang['failed_to_delete_entry'] = 'Echec lors de la suppression de l\'entre %s';
$lang['list_of_entries_to_be_deleted'] = 'Liste des entres  supprimer:';
$lang['sure_permanent_delete_object']='Etes-vous certain de vouloir supprimer dfinitivement cet objet?';
$lang['dn'] = 'DN';

// Deleting attributes
$lang['attr_is_read_only'] = 'L\'attribut "%s" est marqu comme tant en lecture seule dans la configuration de phpLDAPadmin.';
$lang['no_attr_specified'] = 'Aucun nom d\'attributs spcifi.';
$lang['no_dn_specified'] = 'Aucun DN specifi';

// Adding attributes
$lang['left_attr_blank'] = 'Vous avez laisser la valeur de l\'attribut vide. Veuillez s\'il vous plat retourner  la page prcdente et recommencer.';
$lang['failed_to_add_attr'] = 'Echec lors de l\'ajout de l\'attribut.';

// Updating values
$lang['modification_successful'] = 'Modification russie!';
$lang['change_password_new_login'] = 'Votre mot de passe ayant t chang, vous devez maintenant vous logger avec votre nouveau mot de passe.';

// Adding objectClass form
$lang['new_required_attrs'] = 'Nouveaux Attributs Obligatoires';
$lang['requires_to_add'] = 'Cette action ncessite d\'ajouter';
$lang['new_attributes'] = 'nouveaux attributs';
$lang['new_required_attrs_instructions'] = 'Instructions: Afin d\'ajouter cette classe d\'objet, vous devez spcifier';
$lang['that_this_oclass_requires'] = 'dont cette classe d\'objet a besoin. Vous pouvez le faire avec ce formulaire.';
$lang['add_oclass_and_attrs'] = 'Ajout d\' ObjectClass et d\'attributs';

// General
$lang['chooser_link_tooltip'] = 'Cliquer pour choisir un entr(DN)';
$lang['no_updates_in_read_only_mode'] = 'Vous ne pouvez effectuer des mises  jour si le serveur est en lecture seule';
$lang['bad_server_id'] = 'Id de serveur invalide';
$lang['not_enough_login_info'] = 'Informations insuffisantes pour se logguer au serveur. Veuillez, s\'il vous pla, vrifier votre configuration.';
$lang['could_not_connect'] = 'Impossible de se connecter au serveur LDAP.';
$lang['could_not_connect_to_host_on_port'] = 'Impossible de se connecter  "%s" sur le port "%s"';
$lang['could_not_perform_ldap_mod_add'] = 'Echec lors de l\'opration ldap_mod_add.';
$lang['bad_server_id_underline'] = 'serveur_id invalide: ';
$lang['success'] = 'Succs';
$lang['server_colon_pare'] = 'Serveur: ';
$lang['look_in'] = 'Recherche dans: ';
$lang['missing_server_id_in_query_string'] = 'Aucun serveur ID spcifi dans la ligne de requte !';
$lang['missing_dn_in_query_string'] = 'Aucun DN spcifi dans la ligne de requte !';
$lang['back_up_p'] = 'Retour...';
$lang['no_entries'] = 'aucune entre';
$lang['not_logged_in'] = 'Vous n\'tes pas loggu';
$lang['could_not_det_base_dn'] = 'Impossible de dterminer le DN de base';
$lang['please_report_this_as_a_bug']='Veuillez s\'il-vous-plat rapporter ceci comme un bogue.';
$lang['reasons_for_error']='Ceci peut arriver pour plusieurs raisons, les plus probables sont:';
$lang['yes']='Oui';
$lang['no']='Non';
$lang['go']='Go';
$lang['delete']='Suppression';
$lang['back']='Back';
$lang['object']='object';
$lang['delete_all']='Tous les supprimer';
$lang['url_bug_report']='https://sourceforge.net/tracker/?func=add&group_id=61828&atid=498546';
$lang['hint'] = 'Astuce';
$lang['bug'] = 'bogue';
$lang['warning'] = 'Avertissement';
$lang['light'] = 'lumire'; // the word 'light' from 'light bulb'
$lang['proceed_gt'] = 'Continuer &gt;&gt;';


// Add value form
$lang['add_new'] = 'Ajout d\'une nouvelle valeur ';
$lang['value_to'] = 'pour';
$lang['distinguished_name'] = 'Distinguished Name';
$lang['current_list_of'] = 'Liste actuelle de';
$lang['values_for_attribute'] = 'valeur(s) pour l\' attribut';
$lang['inappropriate_matching_note'] = 'Note: Vous obtiendrez une erreur de type "inappropriate matching" si vous n\'avez pas<br />' .
			'dfini une rgle "EQUALITY" pour cet attribut auprs du serveur LDAP.';
$lang['enter_value_to_add'] = 'Entrez la valeur que vous voulez ajouter:';
$lang['new_required_attrs_note'] = 'Note: vous aurez peut-re besoin d\'introduire de nouveaux attributs requis pour cette classe d\'objet';
$lang['syntax'] = 'Syntaxe';

//Copy.php
$lang['copy_server_read_only'] = 'Des mises  jours ne peuvent pas  tre effectues si le serveur est en lecture seule';
$lang['copy_dest_dn_blank'] = 'Vous avez laiss le DN de destination vide.';
$lang['copy_dest_already_exists'] = 'L\'entre de destination (%s) existe dj.';
$lang['copy_dest_container_does_not_exist'] = 'Le conteneur de destination (%s) n\'existe pas.';
$lang['copy_source_dest_dn_same'] = 'Le DN d\'origine et le DN de destination sont identiques.';
$lang['copy_copying'] = 'Copie ';
$lang['copy_recursive_copy_progress'] = 'Progression de la copie rcursive';
$lang['copy_building_snapshot'] = 'Construction de l\'image de l\'arborscence  copier... ';
$lang['copy_successful_like_to'] = 'Copie russite!  Voulez-vous ';
$lang['copy_view_new_entry'] = 'diter cette nouvelle entre';
$lang['copy_failed'] = 'Echec lors de la copie de: ';

//edit.php
$lang['missing_template_file'] = 'Avertissement: le fichier modle est manquant, ';
$lang['using_default'] = 'Utilisation du modle par dfaut.';
$lang['template'] = 'Modle';
$lang['must_choose_template'] = 'Vous devez choisir un modle';
$lang['invalid_template'] = '%s est un modle non valide';
$lang['using_template'] = 'Utilisation du modle';
$lang['go_to_dn'] = 'Aller  %s';




//copy_form.php
$lang['copyf_title_copy'] = 'Copie de ';
$lang['copyf_to_new_object'] = 'vers un nouvel objet';
$lang['copyf_dest_dn'] = 'DN de destination';
$lang['copyf_dest_dn_tooltip'] = 'Le DN de la nouvelle entre  crer lors de la copie de l\'entre source';
$lang['copyf_dest_server'] = 'Destination Serveur';
$lang['copyf_note'] = 'Note: La copie entre diffrents serveurs fonctionne seulement si il n\'y a pas de violation de schma';
$lang['copyf_recursive_copy'] = 'Copier rcursivement les sous-entres de cet object.';
$lang['recursive_copy'] = 'Copie rcursive';
$lang['filter'] = 'Filtre';
$lang['filter_tooltip'] = 'Lors d\'une copie rcursive, seuls les entres correspondant  ce filtre seront copis';

//create.php
$lang['create_required_attribute'] = 'Une valeur n\'a pas t spcifie pour l\'attribut requis %s.';
$lang['redirecting'] = 'Redirection';
$lang['here'] = 'ici';
$lang['create_could_not_add'] = 'L\'ajout de l\'objet au serveur LDAP n\'a pu tre effectue.';
$lang['rdn_field_blank'] = 'Vous avez laisser le champ du RDN vide.';
$lang['container_does_not_exist'] = 'Le containeur que vous avez spcifi (%s) n\'existe pas. Veuillez, s\'il vous plat recommencer.';
$lang['no_objectclasses_selected'] = 'Vous n\'avez slectionner aucun ObjectClasses pour cet objet. Veuillez s\'il vous plat retourner  la page prcdente et le faire.';
$lang['hint_structural_oclass'] = 'Note: Vous devez choisir au moins une classe d\'objet de type structural';

//create_form.php
$lang['createf_create_object'] = 'Creation d\'un objet';
$lang['createf_choose_temp'] = 'Choix d\'un modle';
$lang['createf_select_temp'] = 'Selectionner un modle pour la procdure de cration';
$lang['createf_proceed'] = 'Continuer';
$lang['relative_distinguished_name'] = 'Relative Distinguished Name';
$lang['rdn'] = 'RDN';
$lang['rdn_example'] = '(exemple: cn=MyNewPerson)';
$lang['container'] = 'Containeur';
$lang['alias_for'] = 'Alias pour %s';


//creation_template.php
$lang['ctemplate_on_server'] = 'Sur le serveur';
$lang['ctemplate_no_template'] = 'Aucun modle spcifi dans les variables POST.';
$lang['ctemplate_config_handler'] = 'Votre configuration sccifie un gestionnaire de';
$lang['ctemplate_handler_does_not_exist'] = 'pour ce modle. Cependant, ce gestionnaire n\'existe pas dans le rpertoire \'templates/creation\'.';
$lang['create_step1'] = 'Etape 1 de 2: Nom et classes d\'objet';
$lang['create_step2'] = 'Etape 2 de 2: Dfinition des attributs et de leurs valeurs';
//search.php
$lang['you_have_not_logged_into_server'] = 'Vous ne vous tes pas encore logg auprs du serveur slectionn. Vous ne pouvez y effectuer des recherches.';
$lang['click_to_go_to_login_form'] = 'Cliquer ici pour vous rendre au formulaire de login';
$lang['unrecognized_criteria_option'] = 'Critre non reconnu: ';
$lang['if_you_want_to_add_criteria'] = 'Si vous voulez ajouter vos propres critre  la liste, soyez cetain d\'diter search.php afin de pouvoir les grer.';
$lang['entries_found'] = 'Entres trouves: ';
$lang['filter_performed'] = 'Filtre utilis: ';
$lang['search_duration'] = 'Recherche effectue par phpLDAPadmin en';
$lang['seconds'] = 'secondes';

// search_form_advanced.php
$lang['scope_in_which_to_search'] = 'Porte de la recherche';
$lang['scope_sub'] = 'Sub (le sous-arbre)';
$lang['scope_one'] = 'One (un niveau sous la base)';
$lang['scope_base'] = 'Base (le dn de base)';
$lang['standard_ldap_search_filter'] = 'Un filtre standard de recherche LDAP. Exemple: (&(sn=Smith)(givenname=David))';
$lang['search_filter'] = 'Filtre pour la recherche';
$lang['list_of_attrs_to_display_in_results'] = 'Une liste des attributs  afficher dans les rsultats(spars par des virgules)';
$lang['show_attributes'] = 'Attributs  afficher';

// search_form_simple.php
$lang['search_for_entries_whose'] = 'Chercher les entres dont:';
$lang['equals'] = 'est egal ;';
$lang['starts with'] = 'commence par';
$lang['contains'] = 'contient';
$lang['ends with'] = 'se termine par';
$lang['sounds like'] = 'ressemble ';

// server_info.php
$lang['could_not_fetch_server_info'] = 'Impossible de rcuprer les informations concernant le serveur Ldap';
$lang['server_info_for'] = 'Informations pour le serveur: ';
$lang['server_reports_following'] = 'Le serveur a rapport les informations suivantes';
$lang['nothing_to_report'] = 'Ce serveur n\'a aucunes informations a rapporter.';

//update.php
$lang['update_array_malformed'] = 'update_array n\'est pas bien form. Ceci est peut-tre un bogue de phpLDAPadmin. Pourriez-vous effectuer un rapport de bogue, s\'il vous plat.';
$lang['could_not_perform_ldap_modify'] = 'L\'opration ldap_modify n\'a pu tre effectue.';

// update_confirm.php
$lang['do_you_want_to_make_these_changes'] = 'Voulez-vous effectuer ces changements?';
$lang['attribute'] = 'Attribut';
$lang['old_value'] = 'Ancienne Valeur';
$lang['new_value'] = 'Nouvelle Valeur';
$lang['attr_deleted'] = '[attribut supprim]';
$lang['commit'] = 'Valider';
$lang['cancel'] = 'Annuler';
$lang['you_made_no_changes'] = 'Aucun changement n\'a t effectu';
$lang['go_back'] = 'Retour';

// welcome.php
$lang['welcome_note'] = 'Utilisez le menu de gauche pour la navigation';
$lang['credits'] = 'Crdits';
$lang['changelog'] = 'ChangeLog';
$lang['donate'] = 'Donation';

// view_jpeg_photo.php
$lang['unsafe_file_name'] = 'Nom de fichier non sr: ';
$lang['no_such_file'] = 'Aucun fichier trouv: ';

//function.php
$lang['auto_update_not_setup'] = '"auto_uid_numbers" a t activ pour <b>%s</b> dans votre configuration,
                                  mais vous n\'avez pas spcifi le mcanisme "auto_uid_number_mechanism". Veuiller corriger
                                  ce problme.';
$lang['uidpool_not_set'] = 'Vous avez spcifi l<tt>auto_uid_number_mechanism</tt> comme uidpool
                            dans la configuration du serveur <b>%s</b>, mais vous n\'avez pas spcifi de valeur pour
                            auto_uid_number_uid_pool_dn. Veuillez le spcifier avant de continuer.';
$lang['uidpool_not_exist'] = 'Le uidPool que vous avez spcifi dans votre configuration (%s)
                              n\'existe pas.';
$lang['specified_uidpool'] = 'Le mchanisme "auto_uid_number_mechanism" a t dfini  search dans votre
                              configuration pour le serveur %s, mais la directive "auto_uid_number_search_base" n\'est pad dfinie. Veuillez le spcifier avant de continuer.';
$lang['auto_uid_invalid_credential'] = 'Impossible d\'effectuer un "bind"  %s avec vos droits pour "auto_uid". Veuillez S\'il vous plat vrifier votre fichier de configuration.'; 
$lang['bad_auto_uid_search_base'] = 'Votre fichier de configuration spcifie un invalide auto_uid_search_base pour le serveur %s';
$lang['auto_uid_invalid_value'] = 'Une valeur non valide a t spcifie pour le mchaninsme "auto_uid_number_mechanism" (%s)
                                   dans votre configuration. Seul <tt>uidpool</tt> et <tt>search</tt> sont valides.
                                   Veuillez corriger ce problme.';
$lang['error_auth_type_config'] = 'Erreur: Vous avez une erreur dans votre fichier de configuration.Les valeurs 
                                   supportes pour \'auth_type\' sont \'config\' et \'form\' dans la section $servers.
                                   Vous avez mis \'%s\', ce qui n\'est pas autoris.';
$lang['php_install_not_supports_tls'] = 'Votre installation PHP ne supporte pas TLS.';
$lang['could_not_start_tls'] = 'Impossible de dmarrer TLS.<br />Veuillez,s\'il vous plat, vrifier la configuration de votre serveur LDAP.';                                
$lang['could_not_bind_anon'] = 'Impossible d\'effectuer un "bind" anonyme.';
$lang['anonymous_bind'] = 'Bind Anonyme';
$lang['bad_user_name_or_password'] = 'Mauvais nom d\'utilisateur ou mot de passe. Veuillez recommencer s\'il vous plat.';
$lang['redirecting_click_if_nothing_happens'] = 'Redirection... Cliquez ici si rien ne se passe.';
$lang['successfully_logged_in_to_server'] = 'Login russi sur le serveur %s';
$lang['could_not_set_cookie'] = 'Impossible d\'activer les cookies.';
$lang['ldap_said'] = '<b>LDAP said</b>: %s<br /><br />';
$lang['ferror_error'] = 'Erreur';
$lang['fbrowse'] = 'naviguer';
$lang['delete_photo'] = 'Supprimer la photo';
$lang['install_not_support_blowfish'] = 'Votre installation PHP ne support pas l\'encryption blowfish.';
$lang['install_no_mash'] = 'Votre installation PHP ne supporte pas la fonction mhash(). Impossible de crer un hash SHA.';
$lang['jpeg_contains_errors'] = 'jpegPhoto contient des erreurs<br />';
$lang['ferror_number'] = '<b>Numro de l\'erreur</b>: %s <small>(%s)</small><br /><br />';
$lang['ferror_discription'] = '<b>Description</b>: %s <br /><br />';
$lang['ferror_number_short'] = '<b>Num de l\'erreur</b>: %s<br /><br />';
$lang['ferror_discription_short'] = '<b>Description</b>: (pas de description disponible)<br />';
$lang['ferror_submit_bug'] = 'Est-ce un bogue de phpLDAPadmin? Si c\'est le cas,veuillez s\'il vous plat <a href=\'%s\'>le rapporter</a>.';
$lang['ferror_unrecognized_num'] = 'Numro de l\'erreur non reconnu: ';
$lang['ferror_nonfatil_bug'] = '<center><table class=\'notice\'><tr><td colspan=\'2\'><center><img src=\'images/warning.png\' height=\'12\' width=\'13\' />
             <b>Vous avez trouv un bogue non fatal dans phpLDAPAdmin!</b></td></tr><tr><td>Erreur:</td><td><b>%s</b> (<b>%s</b>)</td></tr><tr><td>Fichier:</td>
             <td><b>%s</b> ligne <b>%s</b>, origine de l\'appel <b>%s</b></td></tr><tr><td>Versions:</td><td>PLA: <b>%s</b>, PHP: <b>%s</b>, SAPI: <b>%s</b>
             </td></tr><tr><td>Serveur Web:</td><td><b>%s</b></td></tr><tr><td colspan=\'2\'><center><a target=\'new\' href=\'%s\'>
             S\'il vous plat, veuillez rapporter ce bogue en cliquant ici</a>.</center></td></tr></table></center><br />';
$lang['ferror_congrats_found_bug'] = 'Flicitations! Vous avez trouv un bogue dans phpLDAPadmin.<br /><br />
	     <table class=\'bug\'>
	     <tr><td>Erreur:</td><td><b>%s</b></td></tr>
	     <tr><td>Niveau:</td><td><b>%s</b></td></tr>
	     <tr><td>Fichier:</td><td><b>%s</b></td></tr>
	     <tr><td>Ligne:</td><td><b>%s</b></td></tr>
        	 <tr><td>Origine de l\'appel:</td><td><b>%s</b></td></tr>
	     <tr><td>PLA Version:</td><td><b>%s</b></td></tr>
	     <tr><td>PHP Version:</td><td><b>%s</b></td></tr>
	     <tr><td>PHP SAPI:</td><td><b>%s</b></td></tr>
	     <tr><td>Serveur Webr:</td><td><b>%s</b></td></tr>
	     </table>
	     <br />
             S\'il vous plat, veuillez rapporter ce bogue en cliquant ici!';

//ldif_import_form
$lang['import_ldif_file_title'] = 'Import de fichier LDIF';
$lang['select_ldif_file'] = 'Slectionner un fichier LDIF:';
$lang['select_ldif_file_proceed'] = 'Continuer &gt;&gt;';

//lldif_import
$lang['add_action'] = 'Ajout de...';
$lang['delete_action'] = 'Supression de...';
$lang['rename_action'] = 'Renommage de...';
$lang['modify_action'] = 'Modification de...';
$lang['warning_no_ldif_version_found'] = 'Aucun numro de version trouv. Version 1 suppos.';
$lang['valid_dn_line_required'] = 'Une ligne avec un dn valide est requis.';
$lang['valid_dn_line_required'] = 'A valid dn line is required.';
$lang['missing_uploaded_file'] = 'Le fichier est manquant.';
$lang['no_ldif_file_specified.'] = 'Aucun fichier LDIFspcifi. Veuillez ressayer, s\'il vous plat.';
$lang['ldif_file_empty'] = 'Le fichier LDIF est vide.';
$lang['file'] = 'Fichier';
$lang['number_bytes'] = '%s bytes';

$lang['failed'] = 'chec';
$lang['ldif_parse_error'] = 'Erreur lors de l\'analyse du fichier LDIF';
$lang['ldif_could_not_add_object'] = 'Impossible d\'ajouter l\'objet:';
$lang['ldif_could_not_rename_object'] = 'Impossible de renommer l\'objet:';
$lang['ldif_could_not_delete_object'] = 'Impossible de supprimer l\'objet:';
$lang['ldif_could_not_modify_object'] = 'Impossible de modifier l\'objet:';
$lang['ldif_line_number'] = 'Numro de ligne';
$lang['ldif_line'] = 'Ligne';

//delete_form
$lang['sure_permanent_delete_object']='Etes-vous certain de vouloir supprimer dfinitivement cet objet?';
$lang['list_of_entries_to_be_deleted'] = 'Liste des entres  supprimer:';
$lang['dn'] = 'DN';

// Exports
$lang['export_format'] = 'Format';
$lang['line_ends'] = 'Fin de ligne';
$lang['must_choose_export_format'] = 'Vous devez slectionner un format pour l\'exportation.';
$lang['invalid_export_format'] = 'Format d\'exportation invalide';
$lang['no_exporter_found'] = 'Aucun exporteur trouv.';
$lang['error_performing_search'] = 'Une erreur a eu lieu lors de la recherche.';
$lang['showing_results_x_through_y'] = 'Affichage  de %s  %s des rsultats.';
$lang['searching'] = 'Recherche...';
$lang['size_limit_exceeded'] = 'Notice, la limite de taille pour la recherche est atteinte.';
$lang['entry'] = 'Entre';
$lang['ldif_export_for_dn'] = 'Export LDIF pour: %s';
$lang['generated_on_date'] = 'Gener par phpLDAPadmin ( http://phpldapadmin.sourceforge.net/ ) le %s';
$lang['total_entries'] = 'Nombre d\'entres';
$lang['dsml_export_for_dn'] = 'Export DSML pour: %s';


// logins
$lang['could_not_find_user'] = 'Impossible de trouver l\'utilisateur "%s"';
$lang['password_blank'] = 'Le champ pour le mot de passe est vide.';
$lang['login_cancelled'] = 'Login interrompu.';
$lang['no_one_logged_in'] = 'Personne n\'est logg  ce serveur.';
$lang['could_not_logout'] = 'Impossible de se dconnecter.';
$lang['unknown_auth_type'] = 'auth_type inconnu: %s';
$lang['logged_out_successfully'] = 'Dconnection russie du serveur %s';
$lang['authenticate_to_server'] = 'Authentification au serveur %s';
$lang['warning_this_web_connection_is_unencrypted'] = 'Attention: Cette connection web n\'est pas crypte.';
$lang['not_using_https'] = 'Vous n\'utilisez pas \'https\'. Le navigateur web transmettra les informations de login en clair.';
$lang['login_dn'] = 'Login DN';
$lang['user_name'] = 'Nom de l\'utilisateur';
$lang['password'] = 'Mot de passe';
$lang['authenticate'] = 'Authentification';

// Entry browser
$lang['entry_chooser_title'] = 'Slection de l\'entre';

// Index page
$lang['need_to_configure'] = 'phpLDAPadmin a besoin d\'tre configur.Pour cela, diter le fichier \'config.php\' . Un exemple de fichier de configuration est fourni dans \'config.php.example\'';

// Mass deletes
$lang['no_deletes_in_read_only'] = 'Les suppressions ne sont pas permises en mode lecure seule.';
$lang['error_calling_mass_delete'] = 'Erreur lors de l\'appel   mass_delete.php.  mass_delete est manquant dans les variables POST.';
$lang['mass_delete_not_array'] = 'La variable POST mass_delete \'est pas un tableau.';
$lang['mass_delete_not_enabled'] = 'La suppression de masse n\'est pas disponible. Veuillez l\'activer dans config.php avant de continuer.';
$lang['mass_deleting'] = 'Suppression en masse';
$lang['mass_delete_progress'] = 'Progrs de la suppression sur le serveur "%s"';
$lang['malformed_mass_delete_array'] = 'Le tableau mass_delete n\'est pas bien form.';
$lang['no_entries_to_delete'] = 'Vous n\'avez slectionn aucune entres  effacer.';
$lang['deleting_dn'] = 'Deleting %s';
$lang['total_entries_failed'] = '%s des %s entres n\'ont pu tre supprimes.';
$lang['all_entries_successful'] = 'Toutes les entres ont t supprimes avec succs.';
$lang['confirm_mass_delete'] = 'Confirmation de la suppression en masse de %s entres sur le serveur %s';
$lang['yes_delete'] = 'Oui, supprimer!';

// Renaming entries
$lang['non_leaf_nodes_cannot_be_renamed'] = 'Vous ne pouvez pas renommer une entre qui a des sous-entres';
$lang['no_rdn_change'] = 'Le RDN n\'a pas t modifi';
$lang['invalid_rdn'] = 'Valeur invalide du RDN';
$lang['could_not_rename'] = 'Impossible de renommer l\'entre';


?>
